const ignores = [
  /**
   * Ignores commits signed off by `dependabot[bot]`.
   *
   * Dependabot commits are formatted in a way that renders their trailers
   * unparsable, and therefore useless. The `'updated-dependencies'` section in
   * these commits makes it so that `git interpret-trailers --parse` yields an
   * empty string. This fails the `trailer-exists` rule because `Signed-off-by`
   * trailers are required.
   *
   * @param {string} commit - Raw commit to evaluate
   * @return {boolean} `true` if `commit` was signed off by `dependabot[bot]`
   */
  (commit) => /Signed-off-by: dependabot\[bot]/.test(commit)
];
var ignores_default = ignores;
export {
  ignores_default as default
};
//# sourceMappingURL=ignores.mjs.map
